@@ -92,6 +92,10 @@ impl ChangeListener {
 impl ServiceChangeListener for ChangeListener {
     async fn changed(&self, service_name: &str, hosts: Vec<Instance>) {
         log::debug!("obtain service[{}] change from nacos: {:?}", service_name, hosts);
+        if self.queue.len() > 256 {
+            log::warn!("service change queue is full, current change will be ignored");
+            return;
+        }
         let endpoints = hosts.into_iter()
             .filter(|instance| instance.healthy && instance.enabled && instance.weight > 0f64)
             .map(|mut instance| {
@@ -108,9 +112,6 @@ impl ServiceChangeListener for ChangeListener {
             cur.remove(&remove_diff);
             let change = Change::Remove(remove_diff.clone());
             self.queue.push(change);
-            if self.queue.len() > 256 {
-                self.queue.pop();
-            }
         }
         
         // insert
@@ -118,9 +119,6 @@ impl ServiceChangeListener for ChangeListener {
             cur.insert(key.clone());
             let change = Change::Insert(key, endpoint);
             self.queue.push(change);
-            if self.queue.len() > 256 {
-                self.queue.pop();
-            }
         }
     }
 }
@@ -135,8 +133,9 @@ pub async fn gen_channel(service_name: &str) -> Channel {
         loop {
             if let Some(change) = queue.pop() {
                 log::info!("service[{}] change: {:?}", name_cloned, change);
-                if let Err(error) = rx.try_send(change) {
-                    log::debug!("failed to modify endpoint list: {}", error)
+                match rx.send(change).await {
+                    Ok(_) => log::info!("update service instance success"),
+                    Err(_) => unreachable!()
                 }
             } else {
                 tokio::time::sleep(std::time::Duration::from_secs(1)).await;
